@font-face
    font-family 'Open Sans'
    src url(../fonts/OpenSans-Regular.woff)
    font-weight normal
    font-style normal

@font-face
    font-family 'Open Sans Bold'
    src url(../fonts/OpenSans-Bold.woff)
    font-weight normal
    font-style normal

@font-face
    font-family 'Open Sans Semibold'
    src url(../fonts/OpenSans-Semibold.woff)
    font-weight normal
    font-style normal

@font-face
    font-family 'VideoJS'
    src url('../fonts/vjs.eot')
    src url('../fonts/vjs.eot?#iefix') format('embedded-opentype'), url('../fonts/vjs.woff') format('woff'), url('../fonts/vjs.ttf') format('truetype')
    font-weight normal
    font-style normal
