// OFFICIAL POPCORN-THEME: FLAX

//FLAX Color scheme
    Green = #323a45
    LightGreen = #656d78
    DarkGreen = #191d22
    LightGrey = #a5a9b0
    DarkGrey = #555b65
    White = #f5f7fa
    Rose = #de5362

//Fonts
    $Font = 'Open Sans'
    $MainFont = 'Open Sans Semibold'
    $MainFontBold = 'Open Sans Bold'
    $AlternateFont = sans-serif
    $ButtonFont = 'Open Sans Semibold'

//Main app
    $BgColor1 = DarkGreen
    $BgColor2 = Green
    $Text1 = White
    $Text2 = LightGrey
    $Text3 = LightGrey
    $Text4 = darken(LightGrey,5)
    $TextError = Green
    $CloseButton = Rose
    $CloseButtonHover = darken(Rose,5)
    $SpinnerColor1 = rgba(#fff,.2)
    $SpinnerColor2 = Rose
    $ScrollBarBg = Green
    $ScrollBarThumb = LightGreen
    $ScrollBarThumbHover = Rose

//Top Bar
    $TitleBarBg = #323a45
    $TitleBarText = #fff
    $TbarIconFilter = none
    $FullScreenButton = #fff
    $FullScreenButtonHover = Rose
    $FilterBarBg = Green
    $FilterBarText = #fff
    $FilterBarTextHover = Rose
    $FilterBarActive = Rose
    $SearchBoxBg = rgba(#000,.2)
    $DropDownBg = Green
    $DropDownBgHover = LightGrey
    $DropDownTextHover = White
    $DropDownText = lighten(LightGrey,10)
    $DropDownOpacity = 1.00
    $FilterBarIcon = lighten(LightGrey,10)
    $FilterBarIconHover = Rose
    $FilterBarIcon-PosterWidth = Rose
    $TopBarShadow = 0px 6px 8px -4px rgba(0, 0, 0, 0)

//Buttons
    $ButtonBg = Rose
    $ButtonBgHover = darken(Rose,4)
    $ButtonBgActive = darken(Rose,6)
    $ButtonBgDisabled = #9ca5ab
    $ButtonBgOk = #27AE60
    $ButtonBgWarning = #cf283a
    $ButtonText = #fff
    $ButtonTextHover = #fff
    $ButtonImgInvert = 0
    $ButtonRadius = 3px

//Checkbox
    $CheckboxBg = #545454
    $CheckboxCheck = #4bfff4

//Posters
    $PosterRadius = 0px
    $PosterHoverBorder = Rose
    $PosterHoverOverlay = rgba(#333, .5)
    $PosterHoverOverlayOpq = rgba(#333, 1)
    $PosterShadow = 0px 0px 0px

//TV Series
    $ShowBgColor1 = lighten(DarkGreen,3)
    $ShowBgColor2 = lighten(DarkGreen,7)
    $ShowOddHighlight = lighten($ShowBgColor1,58%)
    $ShowOddHighlightOp = 0.05
    $EpisodeDetailsBg = lighten(DarkGreen,3)
    $ShowText1 = White
    $ShowText2 = LightGrey
    $SaisonListText = White
    $EpisodeListText = White
    $EpisodeSelectorBg = Rose
    $EpisodeSelectorHover = lighten($ShowBgColor2,6%)
    $EpisodeSelectorHoverTran = lighten($EpisodeSelectorHover,43%)
    $EpisodeSelectorText = #fff
    $ShowWatchedIcon_false = rgba(White,0.3)
    $ShowWatchedIcon_hover = rgba(White,0.6)
    $ShowWatchedIcon_true = White
    $QualitySelectorBg = #df5362
    $QualitySelectorText = $ButtonText

//File selector
    $FileSelectorText = darken(White,5)
    $FileSelectorBg = rgba(0,0,0, 0)
    $FileSelectorShadow = rgba(0, 0, 0, 0)

//Settings
    $SettingsCategoriesText = White
    $SettingsSeparator = rgba(#fff,.1)
    $InputBoxBg = darken(Green,4)
    $InputBoxText = White
    $SettingsText1 = darken(White,5)
    $SettingsText2 = rgba(darken(White,5),.7)
    $SettingsButtonText = #fff
    $SettingsButtonTextHover = #fff

// Notifications
    $NotificationText = #fff
    $NotificationInfo = #191d22
    $NotificationSuccess = #191d22
    $NotificationWarning = #dbb756
    $NotificationOrange = #f07f53
    $NotificationError = #cf283a
    $NotificationBorderColor = White
    $NotificationBtn = #fff
    $NotificationBtnText = #000
    $NotifAlertBg = #191d22
    $NotifAlertText = #fff

//Misc
    $FavoriteColor = #e74c3c
    $WarningColor = #FFFF00
    $PngLogo = brightness(1.0)
    $PngLogo_BgColo1 = brightness(1.0)

//Player
    $PlayerColor = Rose

// OFFICIAL POPCORN-THEME: FLAX - END

@import 'views/app'

//additionnal set of rules
.init-progressbar > div,
.loading .state .loading-progressbar > div
    background-color Rose
.show-quality-container .toggle,
.movie-detail .content-box .bottom-container .movie-quality-container .switch .toggle
    background Rose
#load-more-item
    border 1px solid #333
