// OFFICIAL POPCORN-THEME: FLAT UI

//Fonts
    $Font = 'Open Sans'
    $MainFont = 'Open Sans Semibold'
    $MainFontBold = 'Open Sans Bold'
    $AlternateFont = sans-serif
    $ButtonFont = 'Open Sans Semibold'

//Main app
    $BgColor1 = #fff
    $BgColor2 = #eff0f2
    $Text1 = #34495e
    $Text2 = #d9d9d9
    $Text3 = rgba(#34495e,.8)
    $Text4 = rgba(#34495e,.8)
    $TextError = rgba(#2c3e50,.8)
    $CloseButton = #e74c3c
    $CloseButtonHover = #c0392b
    $SpinnerColor1 = rgba(#fff,.3)
    $SpinnerColor2 = #1ABC9C
    $ScrollBarBg = #ebedef
    $ScrollBarThumb = #1abc9c
    $ScrollBarThumbHover = #16a085

//Top Bar
    $TitleBarBg = #34495e
    $TitleBarText = #fff
    $TbarIconFilter = none
    $FullScreenButton = #fff
    $FullScreenButtonHover = #1abc9c
    $FilterBarBg = #34495e
    $FilterBarText = #fff
    $FilterBarTextHover = #16a085
    $FilterBarActive = #16a085
    $SearchBoxBg = #495c6e
    $DropDownBg = #34495e
    $DropDownBgHover = #1ABC9C
    $DropDownTextHover = #fff
    $DropDownText = #e1e4e7
    $DropDownOpacity = 1.00
    $FilterBarIcon = #fff
    $FilterBarIconHover = #1ABC9C
    $FilterBarIcon-PosterWidth = #bababa
    $TopBarShadow = 0px 6px 8px -4px rgba(0, 0, 0, 0)

//Buttons
    $ButtonBg = #1ABC9C
    $ButtonBgHover = #48c9b0
    $ButtonBgActive = #16a085
    $ButtonBgDisabled = #d1d5d8
    $ButtonBgOk = #27AE60
    $ButtonBgWarning = #F15153
    $ButtonText = #fff
    $ButtonTextHover = #fff
    $ButtonImgInvert = 0
    $ButtonRadius = 6px

//Checkbox
    $CheckboxBg = #34495e
    $CheckboxCheck = #fff

//Posters
    $PosterRadius = 0px
    $PosterHoverBorder = #1ABC9C
    $PosterHoverOverlay = rgba(#34495e, 0.5)
    $PosterHoverOverlayOpq = rgba(#34495e, 1)
    $PosterShadow = 0px 0px 1px

//TV Series
    $ShowBgColor1 = #fff
    $ShowBgColor2 = #eff0f2
    $EpisodeDetailsBg = #fff
    $ShowText1 = #34495e
    $ShowText2 = #7f8c8d
    $ShowOddHighlight = lighten($ShowBgColor1,50%)
    $ShowOddHighlightOp = 0.1
    $SaisonListText = #34495e
    $EpisodeListText = #34495e
    $EpisodeSelectorBg = rgba(#003366,0.6)
    $EpisodeSelectorHover = darken($ShowBgColor2,10%)
    $EpisodeSelectorHoverTran = darken($EpisodeSelectorHover,43%)
    $EpisodeSelectorText = #fff
    $ShowWatchedIcon_false = rgba(#34495e,0.3)
    $ShowWatchedIcon_hover = rgba(#34495e,0.6)
    $ShowWatchedIcon_true = #34495e
    $QualitySelectorBg = $ButtonBg
    $QualitySelectorText = $ButtonText

//File selector
    $FileSelectorText = #34495e
    $FileSelectorBg = rgba(0,0,0, 0.07)
    $FileSelectorShadow = rgba(0, 0, 0, 0)

//Settings
    $SettingsCategoriesText = #16a085
    $SettingsSeparator = #2c3e50
    $InputBoxBg = #34495e
    $InputBoxText = #e1e4e7
    $SettingsText1 = #34495e
    $SettingsText2 = #999
    $SettingsButtonText = #fff
    $SettingsButtonTextHover = #fff

// Notifications
    $NotificationText = #fff
    $NotificationInfo = #3498DB
    $NotificationSuccess = #27AE60
    $NotificationWarning = #dbb756
    $NotificationOrange = #f07f53
    $NotificationError = #f15153
    $NotificationBorderColor = #000
    $NotificationBtn = #000
    $NotificationBtnText = #fff
    $NotifAlertBg = #000
    $NotifAlertText = #fff

//Misc
    $FavoriteColor = #e74c3c
    $WarningColor = #000
    $PngLogo = brightness(1.0)
    $PngLogo_BgColo1 = brightness(0.4)

//Player
    $PlayerColor = #16a085

// OFFICIAL POPCORN-THEME: FLAT - END

@import 'views/app'
