<header id="header"></header>
<div class="dragzone" id="player_drag"></div>
<div class="notification_alert"></div>
<div id="notification"></div>
<div id="changelog-container"></div>
<div id="disclaimer-container"></div>
<div id="about-container"></div>
<div id="issue-container"></div>
<div id="keyboard-container"></div>
<div id="content"></div>
<div id="settings-container"></div>
<div id="movie-detail"></div>
<div id="file-selector-container"></div>
<div id="torrent-collection-container"></div>
<div id="seedbox-container"></div>
<div id="drop-mask"></div>
<div class="drop-indicator top"></div>
<div class="drop-indicator right"></div>
<div class="drop-indicator left"></div>
<div class="drop-indicator bottom"></div>
<div id="player"></div>
