.item
    display inline-block
    margin 10px
    float left
    width 134px
    font-size 0.8em
    &.watched
        opacity 0.4

        .cover
        &.selected
            opacity 1

    .cover
        background-image url(../images/posterholder.png)
        background-size 134px 196px
        width 134px
        height 196px
        border-radius $PosterRadius
        box-shadow $PosterShadow
        cursor pointer

        &.empty
            background-image none

        .cover-overlay
            width 100%
            height 100%
            background-size cover
            background-position center
            opacity 0
            display none

            &.selected
                opacity 1
                display block
                padding 88px 0
                border 2px solid rgba(0,0,0,0)
                border-radius $PosterRadius

                .actions-watched,
                .rating
                    visibility hidden
                    transition none

                &:hover >
                    .actions-watched,
                    .rating
                        visibility visible

            &img
                position absolute
                left 0

            &.fadein
                opacity 1

            &.cover-info-overlay
              padding 88px 0
              background $PosterHoverOverlay
              border-radius $PosterRadius

              &.selected
                  background none

                  &:hover
                      background $PosterHoverOverlay

            .actions-favorites
                float right
                margin-top -80px
                margin-right 7px
                color #FFFFFF
                font-size 1.4 em
                -webkit-transition all 0.5s
                opacity 0.3

                &.selected
                    color $FavoriteColor
                    opacity 1
                &:hover
                    cursor pointer
                    color $ButtonBgActive
                    opacity 1

            .actions-watched
                float left
                margin-top -80px
                margin-left 7px
                color #FFFFFF
                font-size 1.4 em
                -webkit-transition all 0.5s
                opacity 0.3

                &:hover
                    cursor pointer
                    color $ButtonBgActive
                    opacity 1

                &.selected
                    opacity 1

            .rating
                background linear-gradient(to bottom, rgba(206,206,206,0) 0%,rgba(22,22,22,0.69) 69%,rgba(22,22,22,0.95) 100%)
                border-radius $PosterRadius
                bottom 0
                display none
                height auto
                left 0
                margin 0
                padding 10px 5px 5px
                position absolute
                right 0
                text-align left

            .rating-stars
                float left
                margin-top -1px
                font-size 85%

                .rating-star
                    color #ffc900
                    padding-right 0px
                    vertical-align middle

                .rating-star-half
                    color #ffc900
                    width 50%

                .rating-star-half-empty
                    color #a3a5a7
                    vertical-align middle

                .rating-star-empty
                    color #a3a5a7
                    vertical-align middle
                    margin-right 0px

                .rating-star-half-container
                    width 1em
                    height 1em
                    line-height 1em
                    vertical-align middle
                    margin-right 1px

            .rating-value
                font-size 1em
                color #fff
                float right

    &.selected
        > .cover .cover-overlay
            display block
            animation fadeBd 0.5s ease

        .cover
            .cover-info-overlay
                border 2px solid $PosterHoverBorder
                opacity 1
                will-change transform
    .title
        height auto
        margin 6px 0 4px
        color $Text1
        max-width 100%
        overflow hidden
        text-overflow ellipsis
        white-space nowrap
        padding-bottom 2px

    .title2
        font-size 0.85em
        color $Text1
        height auto
        margin -2px 0 3px
        overflow hidden
        text-overflow ellipsis
        white-space nowrap
        padding-bottom 2px

    .year
        font-size 0.85em
        color $Text4
        display inline

    .seasons
        font-size 0.85em
        color $Text4
        display inline
        float right
        margin-top 2px

@keyframes fadeBd
    from
        border-color $PosterHoverOverlayOpq
    to
        border-color $PosterHoverBorder

.load-more,
.search-more
    position relative
    background-size cover
    background-position center center
    width 134px
    height 196px
    border-radius 4px
    border 2px solid rgba(0, 0, 0, 0)
    cursor pointer
    display inline-block
    margin 10px
    float left
    background-color $BgColor1
    opacity 1

    &:hover
        border 2px solid $PosterHoverBorder
        -webkit-transition border 400ms ease

        > #overlay
            display block

    > .loading-container
        display none
        margin 0
        position relative
        width 100%
        height 100%

        .ball,
        .ball1
            position absolute
            top 50%
            left 50%
            margin -25px
            -webkit-transform translate(-50%, -50%)
        .ball1
            margin -15px

    .status-loadmore,
    .status-searchmore
        position absolute
        color $Text1
        padding-bottom 10px
        padding-top 16px
        border-radius 2px
        font-family $MainFont, $AlternateFont
        opacity 0.3
        text-align center
        top 50%
        left 50%
        width 90%
        -webkit-transform translate(-50%, -50%)

        #searchtor
            height 2.8em
            padding 5px 0 48px
            font-size 1.4em

            #searchtor_globe
                padding-right 10px

            #searchtor_mag
                top -5px
                padding-left 15px
                -webkit-text-stroke 2px $BgColor1

    #overlay
        background $PosterHoverOverlay
        height 100%
        width 100%
        position absolute
        opacity 0.8
        display none

.ghost
    width 134px
    height 0
    margin 10px
