// OFFICIAL POPCORN-THEME: DARK (original)

//Fonts
    $Font = 'Open Sans'
    $MainFont = 'Open Sans Semibold'
    $MainFontBold = 'Open Sans Bold'
    $AlternateFont = sans-serif
    $ButtonFont = 'Open Sans Semibold'

//Main app
    $BgColor1 = #17181b
    $BgColor2 = #212225
    $Text1 = #fff
    $Text2 = #c3c5c7
    $Text3 = #a3a5a7
    $Text4 = #5b5b5b
    $TextError = #727272
    $CloseButton = #cccccc
    $CloseButtonHover = #fff
    $SpinnerColor1 = #2187e7
    $SpinnerColor2 = rgba(0,183,229,0.9)
    $ScrollBarBg = #30333c
    $ScrollBarThumb = #83888c
    $ScrollBarThumbHover = #93989c

//Top Bar
    $TitleBarBg = #17181b
    $TitleBarText = #fff
    $TbarIconFilter = none
    $FullScreenButton = #999
    $FullScreenButtonHover = #b2b2b2
    $FilterBarBg = #17181b
    $FilterBarText = #c3c5c7
    $FilterBarTextHover = #fff
    $FilterBarActive = #2d72d9
    $SearchBoxBg = #0d0d0e
    $DropDownBg = #17181b
    $DropDownBgHover = #0b131f
    $DropDownTextHover = #fff
    $DropDownText = #c3c5c7
    $DropDownOpacity = 1.00
    $FilterBarIcon = #909498
    $FilterBarIconHover = #2468cc
    $FilterBarIcon-PosterWidth = #6a6e72
    $TopBarShadow = 0px 6px 8px -4px rgba(0, 0, 0, .9)

//$ButtonBg
    $ButtonBg = #1f375f
    $ButtonBgHover = #225694
    $ButtonBgActive = #2468cc
    $ButtonBgDisabled = #393b3d
    $ButtonBgOk = #27AE60
    $ButtonBgWarning = #F15153
    $ButtonText = #fff
    $ButtonTextHover = #fff
    $ButtonImgInvert = 0
    $ButtonRadius = 3px

//Checkbox
    $CheckboxBg = #545454
    $CheckboxCheck = #4bfff4

//Posters
    $PosterRadius = 4px
    $PosterHoverBorder = #2d75df
    $PosterHoverOverlay = rgba(23, 24, 27, 0.6)
    $PosterHoverOverlayOpq = rgba(23, 24, 27, 1)
    $PosterShadow = 0px 0px 10px

//TV Series
    $ShowBgColor1 = #17181b
    $ShowBgColor2 = #1f2025
    $EpisodeDetailsBg = #1f2025
    $ShowText1 = #fff
    $ShowText2 = #8d9296
    $ShowOddHighlight = lighten($ShowBgColor1,58%)
    $ShowOddHighlightOp = 0.05
    $SaisonListText = #fff
    $EpisodeListText = #8d9296
    $EpisodeSelectorBg = #1b2d4c
    $EpisodeSelectorHover = #26272d
    $EpisodeSelectorHoverTran = lighten($EpisodeSelectorHover,43%)
    $EpisodeSelectorText = #fff
    $ShowWatchedIcon_false = rgba(#fff,0.2)
    $ShowWatchedIcon_hover = rgba(#fff,0.4)
    $ShowWatchedIcon_true = #fff
    $QualitySelectorBg = rgba(43, 110, 210, 0.84)
    $QualitySelectorText = $ButtonText

//File selector
    $FileSelectorText = #eee
    $FileSelectorBg = rgba(255, 255, 255, 0.05)
    $FileSelectorShadow = rgba(0, 0, 0, 0.67)

//Settings
    $SettingsCategoriesText = #2d75df
    $SettingsSeparator = #3a3b3e
    $InputBoxBg = #393b3d
    $InputBoxText = #c3c5c7
    $SettingsText1 = #c3c5c7
    $SettingsText2 = #8a8b8e
    $SettingsButtonText = #e3e5e7
    $SettingsButtonTextHover = #e3e5e7

// Notifications
    $NotificationText = #fff
    $NotificationInfo = #3498DB
    $NotificationSuccess = #27AE60
    $NotificationWarning = #dbb756
    $NotificationOrange = #f07f53
    $NotificationError = #f15153
    $NotificationBorderColor = #000
    $NotificationBtn = #000
    $NotificationBtnText = #fff
    $NotifAlertBg = #000
    $NotifAlertText = #fff

//Misc
    $PngLogo = brightness(1.0)
    $PngLogo_BgColo1 = brightness(1.0)
    $WarningColor = #FFFF00
    $FavoriteColor = #df2d37

//Player
    $PlayerColor = #2d75df

// OFFICIAL POPCORN-THEME: DARK - END

@import 'views/app'
