.button
  cursor pointer
  height 35px
  margin-right 15px
  border-radius $ButtonRadius
  background-clip padding-box
  background-color $ButtonBg
  padding 0 15px
  transition background-color 0.5s
  color $ButtonText
  font-family $MainFont
  font-smoothing antialiased
  text-align center
  font-size 12px
  line-height 34px

  &:hover
    background $ButtonBgHover
    text-decoration none

  &:active
    box-shadow inset 0 1px 4px rgba(0,0,0,0.6)
    background $ButtonBgActive

  &.disabled
    cursor not-allowed
    opacity 0.2
    filter grayscale(100%)
