// OFFICIAL POPCORN-THEME: BLACK AND YELLOW

//Color variables: black & yellow
    Black = #070707
    YellowL = #f3cc16
    YellowM = #ffe035
    YellowD = #ffcc00
    YellowD2 = #e3bd0c

//Fonts
    $Font = 'Open Sans'
    $MainFont = 'Open Sans Semibold'
    $MainFontBold = 'Open Sans Bold'
    $AlternateFont = sans-serif
    $ButtonFont = 'Open Sans Semibold'

//Main app
    $BgColor1 = Black
    $BgColor2 = lighten(Black,5%)
    $Text1 = #fff
    $Text2 = #C9C9C9
    $Text3 = #939597
    $Text4 = #fff
    $TextError = #797979
    $CloseButton = #fff
    $CloseButtonHover = YellowL
    $SpinnerColor1 = YellowD2
    $SpinnerColor2 = YellowD
    $ScrollBarBg = #30333c
    $ScrollBarThumb = YellowD2
    $ScrollBarThumbHover = YellowD

//Top Bar
    $TitleBarBg = Black
    $TitleBarText = #fff
    $TbarIconFilter = none
    $FullScreenButton = #999
    $FullScreenButtonHover = YellowL
    $FilterBarBg = Black
    $FilterBarText = #e9e9e9
    $FilterBarTextHover = #fff
    $FilterBarActive = YellowL
    $SearchBoxBg = #191818
    $DropDownBg = rgba(Black,0.9)
    $DropDownBgHover = rgba(YellowL,0.15)
    $DropDownTextHover = #fff
    $DropDownText = #d9d9d9
    $DropDownOpacity = 0.97
    $FilterBarIcon = $Text1
    $FilterBarIconHover = YellowD
    $FilterBarIcon-PosterWidth = #bababa
    $TopBarShadow = 0px 6px 8px -4px rgba(0, 0, 0, .9)

//Buttons
    $ButtonBg = YellowL
    $ButtonBgHover = YellowM
    $ButtonBgActive = YellowD
    $ButtonBgDisabled = #737577
    $ButtonBgOk = #27AE60
    $ButtonBgWarning = #F15153
    $ButtonText = #000
    $ButtonTextHover = #000
    $ButtonImgInvert = 1
    $ButtonRadius = 3px

//Checkbox
    $CheckboxBg = #232324
    $CheckboxCheck = YellowD

//Posters
    $PosterRadius = 4px
    $PosterHoverBorder = $ButtonBgActive
    $PosterHoverOverlay = rgba(23, 24, 27, 0.6)
    $PosterHoverOverlayOpq = rgba(23, 24, 27, 1)
    $PosterShadow = 0px 0px 10px

//TV Series
    $ShowBgColor1 = $BgColor1
    $ShowBgColor2 = $BgColor2
    $EpisodeDetailsBg = $BgColor1
    $ShowText1 = $Text1
    $ShowText2 = $Text2
    $ShowOddHighlight = lighten($ShowBgColor1,50%)
    $ShowOddHighlightOp = 0.05
    $SaisonListText = $Text1
    $EpisodeListText = $Text2
    $EpisodeSelectorBg = darken(YellowD2,2%)
    $EpisodeSelectorHover = #26272d
    $EpisodeSelectorHoverTran = lighten($EpisodeSelectorHover,43%)
    $EpisodeSelectorText = $ButtonText
    $ShowWatchedIcon_false = rgba(#fff,0.2)
    $ShowWatchedIcon_hover = rgba(#fff,0.4)
    $ShowWatchedIcon_true = #fff
    $QualitySelectorBg = $ButtonBg
    $QualitySelectorText = $ButtonText

//File selector
    $FileSelectorText = #eee
    $FileSelectorBg = rgba(255, 255, 255, 0.05)
    $FileSelectorShadow = rgba(0, 0, 0, 0.67)

//Settings
    $SettingsCategoriesText = YellowD
    $SettingsSeparator = #333
    $InputBoxBg = #232324
    $InputBoxText = $Text2
    $SettingsText1 = $Text2
    $SettingsText2 = $Text3
    $SettingsButtonText = $ButtonText
    $SettingsButtonTextHover = $ButtonText

// Notifications
    $NotificationText = #fff
    $NotificationInfo = #3498DB
    $NotificationSuccess = #27AE60
    $NotificationWarning = #dbb756
    $NotificationOrange = #f07f53
    $NotificationError = #f15153
    $NotificationBorderColor = #000
    $NotificationBtn = #000
    $NotificationBtnText = #fff
    $NotifAlertBg = #000
    $NotifAlertText = #fff

//Misc
    $FavoriteColor = #df2d37
    $WarningColor = #FFA500
    $PngLogo = brightness(1.0)
    $PngLogo_BgColo1 = brightness(1.0)

//Player
    $PlayerColor = YellowL

// OFFICIAL POPCORN-THEME: BLACK AND YELLOW - END

@import 'views/app'
