.init-container
    position absolute
    -webkit-user-select none
    width 90%
    height 70.5%
    position absolute
    -webkit-user-select none   
    opacity 1
    overflow hidden
    margin auto
    left 0
    right 0
    top 20%
    opacity 1
    -webkit-backface-visibility hidden

.init-progressbar
  position relative
  margin-bottom 10px
  margin-top 3%
  background-color #bababa
  border-radius 13px

  & > div
    width 0%
    background-color $ButtonBgActive
    height 5px
    border-radius 13px
    left 0px
    transition background-color 0.5s

.icon-begin
    display block
    margin -7px auto
    height calc(58%)
    max-height 256px

.init-icon-title
    display block
    margin 0 auto
    height calc(11%)
    max-height 52px
    -webkit-filter $PngLogo
    transition -webkit-filter 0.5s

.init-geek-line
    margin 2% 0
    color $Text1
    width 100%
    text-align center
    font-family 23px
    transition color 0.5s

    .heart
        color #e74c3c

.text-begin
    text-align center
    bottom 5%
    position absolute
    width 70%
    margin 0 15%

    #cancel-block
        margin-top 20px
        display none

        .cancel
            color #fff
            font-weight bold

.init-text
    position relative
    color $Text1
    font-family $MainFont
    -webkit-font-smoothing antialiased
    transition color 0.5s, font-family 0.5s

.init-status
    position relative
    color $Text1
    font-family $MainFont
    -webkit-font-smoothing antialiased
    margin-top 1%
    transition color 0.5s, font-family 0.5s

.init-expand
    color $Text1
    font-family $MainFont
    -webkit-font-smoothing antialiased
    text-align center
    width 40%
    z-index 11
    margin auto
    left 0
    right 0
    -webkit-backface-visibility hidden
    position  relative
    top  15%
    transition color 0.5s, font-family 0.5s

#waiting-block
    position fixed
    top calc(90% + 20px)
    width 90%
    text-align center
    display none

    a
        color #fff
        font-weight bold

.loading-container
    display block
    width 50px
    height 50px

    .ball
        background-color rgba(0,0,0,0)
        border 5px solid $SpinnerColor2
        opacity .9
        border-top 5px solid rgba(0,0,0,0)
        border-left 5px solid rgba(0,0,0,0)
        border-radius 50px
        box-shadow 0 0 35px $SpinnerColor1
        width 50px
        height 50px
        margin 0 auto
        -moz-animation spin .5s infinite linear
        -webkit-animation spin .5s infinite linear

    .ball1
        background-color rgba(0,0,0,0)
        border 5px solid $SpinnerColor2
        opacity .9
        border-top 5px solid rgba(0,0,0,0)
        border-left 5px solid rgba(0,0,0,0)
        border-radius 50px
        box-shadow 0 0 15px $SpinnerColor1
        width 30px
        height 30px
        margin-top 10px
        margin-left 10px
        position relative
        top -50px
        -moz-animation spinoff .5s infinite linear
        -webkit-animation spinoff .5s infinite linear

#disclaimer-container .disclaimer
    height  100%
    position absolute
    z-index 10000
    width 100%
    height 100%

    input[type=checkbox]
        position absolute
        overflow hidden
        clip rect(0 0 0 0)
        height 1px
        width 1px
        margin -1px
        padding 0
        border 0

        &+label
            height 15px
            display inline-block
            line-height 15px
            font-size 13px
            font-family $MainFont
            vertical-align middle
            cursor pointer

            &:hover
                opacity 1

        &:checked+label
            opacity 1

            &:after
                opacity 1

    label
        &:before
            content '\f0c8'
            font-family "Font Awesome 6 Free"
            font-weight 900
            font-size 18px
            padding-right 8px
            float left
            position relative
            color $CheckboxBg

        &:after
            content '\f00c'
            font-family "Font Awesome 6 Free"
            font-weight 900
            font-size 12px
            margin-right -14px
            color $CheckboxCheck
            position relative
            float left
            left -21px
            opacity 0
            transition opacity .1s ease-in-out

    .icon-disclaimer
        z-index 1000
        top 20%
        left 5%
        position absolute
        -webkit-filter drop-shadow(5px 2px 10px #fff)
        filter drop-shadow(5px 2px 10px #fff)

    .disclaimer-loading
        z-index 1000
        width 100%
        height 100%
        position absolute
        opacity 0.5
        background-size cover

    .loading-backdrop
        z-index 1000
        width 100%
        height 100%
        position absolute
        opacity 0.8
        background-color #000

    .disclaimer-state
        z-index 1000
        color #fff
        font-family $MainFont
        -webkit-font-smoothing antialiased
        text-align center
        width 50%
        height 100%
        margin auto
        left 40px
        right 0
        -webkit-backface-visibility hidden
        position relative

        .disclaimer-content
            padding-top 14%
            height 100%

            h1
                font-size 25px
                text-transform uppercase

            .dhtEnableSpn
                display block
                font-size 0.9em
                text-align left
                padding 12px 0 0 28px

            .updateNotificationSpn
                display block
                font-size 0.9em
                text-align left
                padding 10px 0 8px 28px

            .disclaimer-text
                font-size 14px
                margin 20px
                overflow auto
                height 60%
                text-align left
                width  100%
                background rgba(0, 0, 0, 0.3)
                padding 7px
                scrollable()
                text-transform uppercase
                text-align justify
                
                h2
                    padding-bottom 8px
                    font-size 16px
                    font-weight 700

                p
                    padding-right 5px
                    line-height 16px

            .btn-accept
                display inline-block
                margin-bottom 0
                font-weight 400
                text-align center
                vertical-align middle
                cursor pointer
                background-image none
                border 1px solid rgba(0, 0, 0, 0)
                white-space nowrap
                padding 6px 12px
                font-size 16px
                line-height 1.428571
                border-radius 4px
                -webkit-user-select none
                color #FFF
                background-color #5CB85C
                border-color #4CAE4C
                outline none
                margin 10px
                text-decoration none

                &:hover
                    background-color #47A447
                    border-color #398439
                    
                &:active
                    box-shadow inset 0 1px 2px rgba(0,0,0,0.6)

            .btn-close
                display inline-block
                margin-bottom 0
                font-weight 400
                text-align center
                vertical-align middle
                cursor pointer
                background-image none
                border 1px solid rgba(0, 0, 0, 0)
                white-space nowrap
                padding 6px 12px
                font-size 16px
                line-height 1.428571
                border-radius 4px
                -webkit-user-select none
                color #FFF
                background-color #D9534F
                border-color #D43F3A
                outline none
                margin 10px
                text-decoration none

                &:hover
                    color #FFF
                    background-color #D2322D
                    border-color #AC2925
                    
                &:active
                    box-shadow inset 0 1px 2px rgba(0,0,0,0.6)

@keyframes fullexpand
    0%
        width 0px
    100%
        width 100%

@keyframes spin
    0%
        transform rotate(0deg)
    100%
        transform rotate(360deg)

@keyframes spinoff
    0%
        transform rotate(0deg)
    100%
        transform rotate(-360deg)

@keyframes blinker
    50%
        opacity 0
