// OFFICIAL POPCORN-THEME: LIGHT

//Color variables: light colors
    White = #f8f8f8
    Grey = #f0f0f0
    GreenL = #00a300
    GreenD = #008f00
    Black = #1d1d1d

//Fonts
    $Font = 'Open Sans'
    $MainFont = 'Open Sans Semibold'
    $MainFontBold = 'Open Sans Bold'
    $AlternateFont = sans-serif
    $ButtonFont = 'Open Sans Semibold'

//Main app
    $BgColor1 = White
    $BgColor2 = Grey
    $Text1 = Black
    $Text2 = #373737
    $Text3 = #515151
    $Text4 = #6b6b6b
    $TextError = #3d3d3d
    $CloseButton = #b8b8b8
    $CloseButtonHover = #008f00
    $SpinnerColor1 = #00a300
    $SpinnerColor2 = rgba(70,186,78,0.9)
    $ScrollBarBg = #d1d1d1
    $ScrollBarThumb =  GreenD
    $ScrollBarThumbHover = GreenL

//Top Bar
    $TitleBarBg = #fafafa
    $TitleBarText = #000
    $TbarIconFilter = invert(100%)
    $FullScreenButton = #3d3d3d
    $FullScreenButtonHover = GreenD
    $FilterBarBg = #fafafa
    $FilterBarText = #414141
    $FilterBarTextHover = Black
    $FilterBarActive = GreenD
    $SearchBoxBg = Grey
    $DropDownBg = White
    $DropDownBgHover = Grey
    $DropDownTextHover = Black
    $DropDownText = #373737
    $DropDownOpacity = 0.97
    $FilterBarIcon = $Text2
    $FilterBarIconHover = GreenD
    $FilterBarIcon-PosterWidth = $Text4
    $TopBarShadow = 0px 6px 8px -4px rgba(0, 0, 0, .9)

//Buttons
    $ButtonBg = #00a300
    $ButtonBgHover = #00b700
    $ButtonBgActive = #008f00
    $ButtonBgDisabled = #d8d8d8
    $ButtonBgOk = #27AE60
    $ButtonBgWarning = #F15153
    $ButtonText = #fff
    $ButtonTextHover = #fff
    $ButtonImgInvert = 0
    $ButtonRadius = 3px

//Checkbox
    $CheckboxBg = #d8d8d8
    $CheckboxCheck = GreenD

//Posters
    $PosterRadius = 4px
    $PosterHoverBorder = GreenL
    $PosterHoverOverlay = rgba(23, 24, 27, 0.6)
    $PosterHoverOverlayOpq = rgba(23, 24, 27, 1)
    $PosterShadow = 0px 0px 10px

//TV Series
    $ShowBgColor1 = $BgColor1
    $ShowBgColor2 = $BgColor2
    $EpisodeDetailsBg = $BgColor1
    $ShowText1 = $Text1
    $ShowText2 = $Text2
    $ShowOddHighlight = lighten($ShowBgColor1,50%)
    $ShowOddHighlightOp = 0.1
    $SaisonListText = Black
    $EpisodeListText = $Text2
    $EpisodeSelectorBg = GreenD
    $EpisodeSelectorHover = darken($ShowBgColor2,10%)
    $EpisodeSelectorHoverTran = darken($EpisodeSelectorHover,43%)
    $EpisodeSelectorText = $ButtonText
    $ShowWatchedIcon_false = rgba(#1d1d1d,0.3)
    $ShowWatchedIcon_hover = rgba(#1d1d1d,0.7)
    $ShowWatchedIcon_true = rgba(#1d1d1d,0.95)

//File selector
    $FileSelectorText = #1d1d1d
    $FileSelectorBg = rgba(0,0,0, 0.07)
    $FileSelectorShadow = rgba(0, 0, 0, 0.67)

//Settings
    $SettingsCategoriesText = GreenD
    $SettingsSeparator = #aaa
    $InputBoxBg = #d8d8d8
    $InputBoxText = $Text1
    $SettingsText1 = $Text1
    $SettingsText2 = $Text4
    $SettingsButtonText = $ButtonText
    $SettingsButtonTextHover = $ButtonText
    $QualitySelectorBg = $ButtonBg
    $QualitySelectorText = $ButtonText

// Notifications
    $NotificationText = #fff
    $NotificationInfo = #3498DB
    $NotificationSuccess = #27AE60
    $NotificationWarning = #dbb756
    $NotificationOrange = #f07f53
    $NotificationError = #f15153
    $NotificationBorderColor = #000
    $NotificationBtn = #000
    $NotificationBtnText = #fff
    $NotifAlertBg = #000
    $NotifAlertText = #fff

//Misc
    $FavoriteColor = #ee1111
    $WarningColor = #A52A2A
    $PngLogo = brightness(0.3)
    $PngLogo_BgColo1 = brightness(0.3)

//Player
    $PlayerColor = GreenL

// OFFICIAL POPCORN-THEME: LIGHT - END

@import 'views/app'
