.torrent-collection-container
    height 100%
    width 100%
    position fixed
    background-color $BgColor1
    -webkit-user-select none
    opacity 1

    > .spinner
        position fixed
        width 100%
        height 100%
        background rgba(0, 0, 0, 0.4) center center no-repeat
        pointer-events all
        z-index 1

        .loading-container
            margin 50vh auto 0px
            opacity .8

    .margintop
        height 100px

    .content
        margin 0 auto
        width 85%
        height calc(100% - 140px)
        color $TextError
        font-weight 100
        font-family $Font, $AlternateFont
        font-size 17px

        #savedtorrentslabel
            font-size 50px
            opacity 0.07
            left 78px
            top 126px
            text-align left
            position absolute
            z-index -1
            cursor pointer
            transition opacity .3s

            &:hover
                opacity 0.27

        #searchresultslabel
            font-size 48px
            opacity 0.07
            left 76px
            top 126px
            text-align left
            position absolute
            z-index -1

        #savedtorrentslabeltext,
        #searchresultslabeltext
            font-size 36px
            font-family $MainFontBold
            font-style normal
            opacity 0.07
            left 134px
            top 134px
            text-align left
            position absolute
            z-index -1

        .onlinesearch
            position relative
            padding-left 190px
            width 736px
            margin 0 auto
            z-index 2
            
            .search_in
                background-color $InputBoxBg
                margin 0px 0px 15px -88px
                padding 9px 0px 9px 6px
                display none
                position absolute
                height 30px
                min-width 498px

                span
                    color $InputBoxText
                    font-family $MainFont
                    font-size 12px
                    float left
                    height 12px
                    padding 0px 8px 10px 8px
                    vertical-align top
                    opacity 0.9
                    transition opacity .1s ease-in

                    &:hover
                        opacity 1

                input[type=checkbox]
                    &.sengine-checkbox
                        position absolute
                        overflow hidden
                        clip rect(0 0 0 0)
                        height 1px
                        width 1px
                        margin -1px
                        padding 0
                        border 0

                    &.sengine-checkbox+label
                        height 12px
                        display inline-block
                        line-height 12px
                        font-size 11px
                        font-family $MainFont
                        vertical-align middle
                        cursor pointer
                        color $DropDownText
                        opacity 0.25
                        filter grayscale(1)
                        transition opacity .1s ease-in

                        &:hover
                            opacity 1
                            filter none

                    &.sengine-checkbox:checked+label
                        opacity 1
                        filter none
                        &:after
                            opacity 1
                            filter none

                label
                    &:before
                        content '\f0c8'
                        font-family "Font Awesome 6 Free"
                        font-weight 900
                        font-size 12px
                        width 0px
                        margin-left -1px
                        float left
                        position relative
                        color $CheckboxBg
                        visibility hidden
                    &:after
                        content '\f00c'
                        font-family "Font Awesome 6 Free"
                        font-weight 900
                        font-size 10px
                        margin-right -14px
                        color $CheckboxCheck
                        position relative
                        float left
                        left -15px
                        opacity 0
                        transition opacity .1s ease-in-out
                        visibility hidden

                    img
                        height 14px
                        vertical-align middle
                        margin -2px 4px 0 -4px

            .engine-selector
                position absolute
                margin-left -160px

                div
                    width 30px
                    height 30px
                    opacity .3
                    float left
                    cursor pointer
                    transition opacity .1s ease-in

                    &.active
                        opacity 1

            input[type="text"]
                border 0 !important
                line-height 16px
                background-color $InputBoxBg
                resize none
                color $InputBoxText
                font-family $MainFont, $AlternateFont
                font-size 13px
                padding-left 10px
                cursor text
                outline 0 !important
                height 30px
                min-width 410px
                margin-right 2px

            .online-search
                padding 5px 0 5px 5px
                border-radius 50%
                cursor pointer
                color $SettingsText1
                opacity 0.5
                transition opacity .3s, color .3s

                &:hover
                    opacity 1

                &.active
                    opacity 1
                    color $FilterBarIconHover

            .togglesengines
                cursor pointer
                color $SettingsText1
                opacity 0.5
                transition opacity .3s
                font-size 14px
                line-height 24px
                vertical-align text-top

                &:hover
                    opacity 1

            .dropdown
                position absolute
                margin-top 9px
                margin-left -88px
                border-bottom 3px solid $BgColor1
                border-right 3px solid $BgColor1
                z-index 1000

                select
                    position relative
                    padding-left 5px
                    border 0 !important
                    -webkit-appearance none
                    height 30px
                    width 85px
                    line-height 25px
                    margin-top -9px
                    background-color $InputBoxBg
                    cursor pointer
                    color $InputBoxText
                    font-family $MainFont, $AlternateFont
                    font-size 13px
                    float left
                    outline 0
                    padding-right 15px

                option
                    background $InputBoxBg
                    border 0 !important
                    outline 0

                .dropdown-arrow
                    width 0
                    height 0
                    border-left 4px solid transparent
                    border-right 4px solid transparent
                    border-top 5px solid $SettingsText1
                    top 4px
                    margin-left -13px
                    position relative
                    float left
                    cursor pointer

        .notorrents-info
            display block
            top 246px
            position absolute
            text-align center
            width 85%

            .notorrents-frame
                margin 0 auto
                color $TextError
                text-align center
                transition all .3s

                .notorrents-icon
                    font-size 180px
                    padding-top 50px
                    padding-bottom 25px

                .notorrents-message
                    font-family $MainFont
                    font-size 24px

        .torrents-info,
        .onlinesearch-info
            display none
            margin 60px auto
            height calc(100% - 100px)
            color $Text1
            font-family $Font, $AlternateFont
            font-size 17px
            text-align center
            scrollable()

            .online-back
                position fixed
                font-size 0.9em
                color $FilterBarIcon
                cursor pointer
                left 50%
                top 105px
                margin-left 205px
                padding 3px 5px
                border-radius 50%
                z-index 10
                transition color .3s

            ul
                &.file-list
                    overflow hidden
                    cursor pointer

                li.file-item,
                li.result-item
                    margin-top 2px
                    margin-bottom 2px
                    text-align left
                    cursor pointer
                    color $SettingsText1
                    height 40px
                    padding-left 40px
                    padding-right 50px
                    font-family $MainFont
                    font-size 15px
                    overflow hidden

                    &:nth-child(odd)
                        background $ShowBgColor2

                    &.disabled
                        cursor not-allowed
                        opacity 0.7
                        filter grayscale(30%)

                    a
                        color $EpisodeListText
                        text-decoration blink
                        width 100%
                        padding 12px 0
                        display block
                        transition all 0.3s
                        overflow hidden
                        white-space nowrap
                        text-overflow ellipsis
                        margin-left 2px

                    &:hover
                        background $EpisodeSelectorHover

                    .item-delete,
                    .item-rename
                        position relative
                        color $SettingsText1
                        opacity 0.12
                        transition all 0.3s
                        cursor pointer
                        left calc(100% + 18px)
                        top -58px
                        padding 3px
                        border-radius 50%

                        &:hover
                            opacity 1

                    .item-rename
                        left calc(100% - 38px)

                    .item-icon
                        position relative
                        font-family "Font Awesome 6 Free"
                        font-weight 900
                        font-style normal
                        font-size 15px
                        height 15px
                        width 15px
                        color $SettingsText1
                        opacity 0.7
                        left -33px
                        top -35px
                        transition opacity .3s
                        padding 8px 20px 20px 8px

                        &.torrent-icon:before
                            content '\f15b'
                        &.magnet-icon:before
                            content '\f076'

                        &.magnet-icon
                            img
                                height 16px

                        &.magnet-icon,
                        &.torrent-icon
                            &:hover
                                cursor pointer
                                opacity 1

                    .online-health
                        position relative
                        color $SettingsText1
                        opacity 0.5
                        font-style normal
                        font-size .9em
                        left calc(100% - 150px)
                        top -55px
                        min-width 90px
                        text-align right
                        display inline-block

                    .online-size
                        position relative
                        color $SettingsText1
                        opacity 0.5
                        font-style normal
                        font-size .9em
                        left calc(100% - 135px)
                        top -55px
                        min-width 70px
                        text-align right
                        display inline-block

                li.result-item a
                    width calc(100% - 160px)

        .onlinesearch-info
            ul
                li.file-item,
                li.result-item
                    .item-icon
                        opacity 1

                        &.magnet-icon:before
                            content ''

        .collection-actions
            position absolute
            color $SettingsText1
            top 6px
            margin-left 462px

            .collection-paste,
            .collection-import
                transition all 0.3s
                cursor pointer
                opacity 0.3
                padding 0 5px 8px 5px
                border-radius 50%

                &:hover
                    opacity 1

                &.disabled
                    opacity 0.15
                    cursor not-allowed

                    &:hover
                        opacity 0.15

            .collection-import-hidden
                display none

            .tooltip
                min-width 150px
