#notification .notification
    display block
    position absolute
    top 70px
    border-radius 3px
    height auto
    min-width 300px
    -webkit-user-select none
    opacity 0.9
    right 60px
    z-index 5000
    font-size 13px
    font-weight bold
    text-align center
    line-height 27px
    padding 11px 15px
    color $NotificationText
    border 1px solid rgba($NotificationBorderColor,.7)
    transition all .5s

    &:empty
        display none

    &:hover
        opacity 1

    &.info
        background $NotificationInfo

    &.success
        background $NotificationSuccess

    &.warning
        background $NotificationWarning

    &.danger
        background $NotificationOrange

    &.error
        background $NotificationError

    .close
        position absolute
        top 6px
        right 8px
        opacity 0.7
        color white
    &:hover
        opacity 1

    .btn-grp
        position relative
        top 6px
        padding-bottom 6px
        margin-right auto
        margin-left auto

    .btn
        background $NotificationBtn
        opacity .4
        color $NotificationBtnText
        transition all .5s

        &:hover
            background $NotificationBtn
            opacity .6

        &:active
            box-shadow inset 0 1px 4px rgba(0,0,0,0.6)
            box-shadow inset 0 1px 4px rgba(0,0,0,0.6)
            background $NotificationBtn
            opacity .7

        label
            cursor pointer

    .btn.chnglog
        margin-right 5px

    h1
        font-size 20px

    p
        font-weight 100
        line-height 20px


