<div class="windows-titlebar">
  <img class="icon" src="/src/app/images/icon.png" alt="icon">

  <h1 class="windows-titlebar-title"><%= Settings.projectName %></h1>

  <div class="events img-<%= events() %>"></div>

  <div class="window-controls">
    <button class="window-control window-minimize">
      <div class="control-icon window-minimize-icon"></div>
    </button>
    <button class="window-control window-maximize">
      <div class="control-icon window-maximize-icon"></div>
    </button>
    <button class="window-control window-close">
      <div class="control-icon window-close-icon"></div>
    </button>
  </div>
</div>
