support-for-ie = false
vendor-prefixes = webkit official

@import 'nib'

global-reset()

$TitleHeight = 32px
$FilterBarHeight = 35px
$HeaderHeight = 65px
$MovieListPadding = calc(100% - 67px)

@import 'fonts'
@import 'misc'
@import 'bootstrap_theme'
@import 'button'
@import 'player'
@import 'videojs'
@import 'dropdowns'
@import 'main_window'
@import 'initializing'
@import 'title_bar'
@import 'windows_titlebar'
@import 'filter_bar'
@import 'list'
@import 'item'
@import 'movie_detail'
@import 'movie_error'
@import 'show_detail'
@import 'torrent_list'
@import 'about'
@import 'keyboard'
@import 'file_selector'
@import 'torrent_collection'
@import 'settings_container'
@import 'loading'
@import 'notification'
@import 'seedbox'
