#movie-error
    .button
        position absolute
        cursor pointer
        height 35px
        width 250px
        top 0
        margin-top 275px
        border-radius $ButtonRadius
        background-clip padding-box
        background-color $ButtonBg
        padding 0 15px
        transition background-color 0.5s
        color $ButtonText
        font-family $MainFont
        font-smoothing antialiased
        text-align center
        font-size 12px
        line-height 34px

        &:hover
            background $ButtonBgHover
            text-decoration none

        &:active
            box-shadow inset 0 1px 4px rgba(0,0,0,0.6)
            background $ButtonBgActive

        .button-text
            margin-left 12px
            margin-right 12px

            &:after
                content ''
                width 70%
                height 100%
                top 0
                left 0
                position absolute

            i
                font-size 14px

    .retry-button
        visibility hidden
        position relative
        display inline-block

    .change-api,
    .online-search
        visibility hidden
        width auto
        min-width 250px
        max-width 300px
        text-overflow ellipsis
        white-space nowrap
        position relative
        display inline-block
